@@ -16,7 +16,7 @@
 #include <KLocalizedString>
 #include <KPropertiesDialog>
 #include <KFileItem>
-#include <KMimeTypeTrader>
+#include <KApplicationTrader>
 #include <KActionCollection>
 #include <KMessageBox>
 
@@ -291,7 +291,7 @@ Selector::Selector(QWidget *parent, KActionCollection *actionCollection)
   deleteFileAction = actionCollection->addAction(QStringLiteral("deleteFile"), this, SLOT(deleteFile()));
   deleteFileAction->setText(i18n("Delete File"));
   deleteFileAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
-  deleteFileAction->setShortcut(QKeySequence(Qt::SHIFT + Qt::Key_Delete));
+  deleteFileAction->setShortcut(QKeySequence(Qt::SHIFT | Qt::Key_Delete));
   menu->addAction(deleteFileAction);
 
   action = actionCollection->addAction(QStringLiteral("properties"), this, SLOT(properties()));
@@ -679,7 +679,7 @@ void Selector::populateOpenMenu()
   KFileItem fileItem(sourceUrl);
   QString mimeType(fileItem.determineMimeType().name());
 
-  const KService::List services = KMimeTypeTrader::self()->query(mimeType);
+  const KService::List services = KApplicationTrader::queryByMimeType(mimeType);
 
   for (const KService::Ptr &service : services)
   {
